<div class="columns" role="navigation" aria-label="Secondary">
  <div class="column">
    <ul class="nav-spaced">
      <li><a href="/help/contact">Contact</a></li>
      <li><a href="https://twitter.com/arxiv">Find us on Twitter</a></li>
    </ul>
  </div>
  <div class="column">
    <ul class="nav-spaced">
      <li><a href="https://blogs.cornell.edu/arxiv/">Blog - the latest news</a></li>
      <li><a href="https://confluence.cornell.edu/display/arxivpub/arXiv+Public+Wiki">Wiki - project documentation</a></li>
    </ul>
  </div>
  <div class="column">
    <ul class="nav-spaced">
      <li><a href="mailto:web-accessibility@cornell.edu">Web Accessibility Help</a></li>
      <li><a href="/help">Help with using arXiv</a></li>
    </ul>
  </div>
</div>
