/** All of the custom styles for arXiv-NG - related to specific graphical style rather than overrides of Bulma - are placed here. **/

/* line-height property here sets vertical alignment to center */
header h1
  font-size: 2em
  font-weight: bold
  padding: .25em 0 .5em

footer
  background-color: #9b9b9b
  color: #fff
  padding: .5em 2em
  a
    color: #fff
    &:visited
      color: #fff
    &:hover,
    &:active
      border-bottom: 1px dotted #fff

.nav-spaced
  line-height: 2

.content
  h1
    font-size: 1.5em
    font-weight: bold

.attribution
  align-items: center
  background-color: $cul-gray
  color: #fff
  line-height: 1

.identity
  background-color: $cul-red
  color: #fff
  padding: 0 .75em
  a
    color: #fff
    &:visited
      color: #fff
    &:hover
      border-bottom: 1px dotted #fff
      color: #fff

.logo
  height: 45px
  margin: .2em
  vertical-align: middle

.sponsors
  font-size: .9em
  font-weight: 600
  line-height: 1.3
  margin: 4px
  padding-right: .75em
  text-align: right

/* specific styles for search lists with classic dl/dt/dd structure and classes */
.list-identifier
  font-weight: 600

.list-title
  font-size: 1.25em
  font-weight: 600

dt
  margin-top: 1em
